==> planeshift-0.3.016.tar.bz2: planeshift-0.3.016/src/client/gui/pawsbookreadingwindow.h <==
/*
 * pawsbookreadingwindow.h - Author: Daniel Fryer, based on work by Andrew Craig
 *
 * Copyright (C) 2003 Atomic Blue (info@planeshift.it, http://www.atomicblue.org)
 *
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation (version 2 of the License)
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 */

#ifndef PAWS_BOOK_READING_WINDOW_HEADER
#define PAWS_BOOK_READING_WINDOW_HEADER

#include "paws/pawswidget.h"

class pawsTextBox;
class pawsMultiLineTextBox;

/** A window that shows the description of an item.
 */
class pawsBookReadingWindow : public pawsWidget, public psClientNetSubscriber
{
public:

    virtual ~pawsBookReadingWindow() {};

    bool PostSetup();

    void HandleMessage( MsgEntry* message );
    bool OnButtonPressed( int mouseButton, int keyModifier, pawsWidget* widget );

private:
    csRef<MsgHandler> msgHandler;

    pawsTextBox*            name;
    pawsMultiLineTextBox*   description;
};

CREATE_PAWS_FACTORY( pawsBookReadingWindow );


#endif

==> planeshift-0.3.017.tar.bz2: planeshift-0.3.017/src/client/gui/pawsbookreadingwindow.h <==
/*
 * pawsbookreadingwindow.h - Author: Daniel Fryer, based on work by Andrew Craig
 *
 * Copyright (C) 2003 Atomic Blue (info@planeshift.it, http://www.atomicblue.org)
 *
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation (version 2 of the License)
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 */

#ifndef PAWS_BOOK_READING_WINDOW_HEADER
#define PAWS_BOOK_READING_WINDOW_HEADER

#include "paws/pawswidget.h"

class pawsTextBox;
class pawsMultiLineTextBox;

/** A window that shows the description of an item.
 */
class pawsBookReadingWindow : public pawsWidget, public psClientNetSubscriber
{
public:
//    pawsBookReadingWindow(){};
//    virtual ~pawsBookReadingWindow() {};

    bool PostSetup();

    void HandleMessage( MsgEntry* message );
    bool OnButtonPressed( int mouseButton, int keyModifier, pawsWidget* widget );

private:
//Commented out because it made some IncRef and DecRef stuff mysteriously invisible!
    csRef<MsgHandler> msgHandler;

    pawsTextBox*            name;
    pawsMultiLineTextBox*   description;
    pawsWidget*             writeButton;
    
    bool shouldWrite;
    int slotID;
    int containerID;
    int parentContainerID;
};

CREATE_PAWS_FACTORY( pawsBookReadingWindow );


#endif
